| SSTD_R1 | R Documentation |
SSTD solves the rank-1 approximation to the a p-by-p-by-q sparse symmetric tensor \mathcal{D}:
\min_{\Lambda, v, u} ||\mathcal{D} - \Lambda v \circ v \circ u||_F^2
subject to
\Lambda > 0, v \in R^p, u \in R^q, ||v||_2 = ||u||_2 = 1, ||v||_0 <= R
The solution \Lambda is the sparse leading tensor eigenvalue (sLTE),
v is the sparse leading tensor eigenvector, and u is the loading vector.
The Symmetric Penalized Matrix Decomposition symmPMD() is used in the iterative algorithm.
SSTD_R1(
T_obs,
u_ini,
v_ini,
max_iter = 20,
sumabs = 0.5,
niter = 20,
rho = 1000,
tol = 10^(-3),
verbose = FALSE
)
T_obs |
array, a p-by-p-by-q tensor; each p-by-p layer in |
u_ini |
vector, with length q; the random initialization for loading vector |
v_ini |
vector, with length p; the random initialization for tensor eigenvector |
max_iter |
integer, the maximal iteration number |
sumabs |
number, the number specify the sparsity level in the matrix/tensor eigenvector; |
niter |
integer, the number of iterations to use in the PMD algorithm (see |
rho |
number, a large positive constant adding to the diagonal elements to ensure positive definiteness in symmetric matrix spectral decomposition |
tol |
number, the tolerance threshold for SSTD convergence; if the error difference between two iterations is smaller than |
verbose |
logic variable, whether to print the progress during permutation tests |
a list containing the following:
u_hat |
vector, with length q; the estimated loading vector |
v_hat |
vector, with length p; the estimated tensor eigenvector |
gamma_hat |
number, the estimated sLTE |
Hu, J., Weber, J. N., Fuess, L. E., Steinel, N. C., Bolnick, D. I., & Wang, M. (2025). A spectral framework to map QTLs affecting joint differential networks of gene co-expression. PLOS Computational Biology, 21(4), e1012953.
Sun, W. W., Lu, J., Liu, H., & Cheng, G. (2017). "Provable sparse tensor decomposition." Journal of the Royal Statistical Society Series B: Statistical Methodology, 79(3), 899-916.
symmPMD()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.