| sLME | R Documentation |
Calculate the sLME given a matrix D.
For any symmetric matrix D, sLME test statistic is defined as
max{ sEig(D), sEig(-D) }
where sEig() is the sparse leading eigenvalue, defined as
max_{v} v^T A v
subject to
||v||_2 \leq 1, ||v||_1 \leq s.
sLME(Dmat, rho = 1000, sumabs.seq = 0.2, niter = 20, trace = FALSE)
Dmat |
p-by-p numeric matrix, the differential matrix |
rho |
a large positive constant such that |
sumabs.seq |
a numeric vector specifing the sequence of sparsity parameters, each between |
niter |
the number of iterations to use in the PMD algorithm (see |
trace |
whether to trace the progress of PMD algorithm (see |
A list containing the following components:
sumabs.seq |
the sequence of sparsity parameters |
rho |
a positive constant to augment the diagonal of the differential matrix
such that |
stats |
a numeric vector of test statistics when using different sparsity parameters
(corresponding to |
sign |
a vector of signs when using different sparsity parameters (corresponding to |
v |
the sequence of sparse leading eigenvectors, each row corresponds to one sparsity
parameter given by |
leverage |
the leverage score for genes (defined as |
Zhu, Lingxue, et al. "Testing high-dimensional covariance matrices, with application to detecting schizophrenia risk genes." The annals of applied statistics 11.3 (2017): 1810.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.